@@ -14,9 +14,5 @@ rowRanks <- function(x,method = "average",descending = FALSE,stable = FALSE, par
 
 #[export]
 colRanks <- function(x,method = "average",descending = FALSE,stable = FALSE,parallel = FALSE) {
-	if(parallel){
-  		.Call(Rfast_col_ranks_p,x,method,descending,stable)
-	}else{
-		.Call(Rfast_col_ranks,x,method,descending,stable)
-	}
+	.Call(Rfast_col_ranks,x,method,descending,stable,parallel)
 }
\ No newline at end of file
