@@ -19,15 +19,15 @@ SEXP Rfast_col_cum_mins(SEXP x);
 SEXP Rfast_col_cum_prods(SEXP x);
 SEXP Rfast_col_meds(SEXP xSEXP,SEXP na_rmSEXP,SEXP parallelSEXP);
 SEXP Rfast_col_min_indices(SEXP xSEXP);
-SEXP Rfast_col_min(SEXP x);
+SEXP Rfast_col_min(SEXP x,SEXP parallelSEXP);
 SEXP Rfast_col_sums(SEXP xSEXP,SEXP SEXPindices,SEXP na_rmSEXP);
-SEXP Rfast_col_min_max(SEXP x);
+SEXP Rfast_col_min_max(SEXP x, SEXP parallelSEXP);
 SEXP Rfast_col_max_indices(SEXP xSEXP);
-SEXP Rfast_col_max(SEXP x);
+SEXP Rfast_col_max(SEXP x, SEXP parallelSEXP);
 SEXP Rfast_col_means(SEXP xSEXP, SEXP parallelSEXP);
 SEXP Rfast_col_nth(SEXP xSEXP,SEXP ySEXP,SEXP num_of_nths,SEXP descendSEXP,SEXP na_rmSEXP,SEXP indexSEXP);
 SEXP Rfast_col_len_sort_un_int(SEXP xSEXP);
-SEXP Rfast_col_ranks(SEXP xSEXP,SEXP methodSEXP,SEXP descendSEXP,SEXP stableSEXP);
+SEXP Rfast_col_ranks(SEXP xSEXP,SEXP methodSEXP,SEXP descendSEXP,SEXP stableSEXP,SEXP parallelSEXP);
 SEXP Rfast_col_tabulate(SEXP xSEXP,SEXP nrowwSEXP);
 SEXP Rfast_col_shuffle(SEXP xSEXP);
 SEXP Rfast_col_true(SEXP xSEXP);
@@ -242,11 +242,8 @@ SEXP Rfast_quasi_poisson_only(SEXP xSEXP,SEXP ySEXP,SEXP ylogySEXP,SEXP tolSEXP,
 
 SEXP Rfast_col_all_p(SEXP xSEXP);
 SEXP Rfast_col_count_values_p(SEXP xSEXP,SEXP valuesSEXP);
-SEXP Rfast_col_max_p(SEXP nSEXP);
-SEXP Rfast_col_min_p(SEXP nSEXP);
 SEXP Rfast_col_nth_p(SEXP xSEXP,SEXP ySEXP,SEXP descendSEXP,SEXP na_rmSEXP,SEXP indexSEXP);
 SEXP Rfast_col_order_p(SEXP xSEXP,SEXP stableSEXP,SEXP descendingSEXP);
-SEXP Rfast_col_ranks_p(SEXP xSEXP,SEXP methodSEXP,SEXP descendSEXP,SEXP stableSEXP);
 SEXP Rfast_col_sums_p(SEXP xSEXP);
 SEXP Rfast_mat_mult_p(SEXP xSEXP,SEXP ySEXP,SEXP txSEXP,SEXP tySEXP);
 SEXP Rfast_row_all_p(SEXP xSEXP);
@@ -273,15 +270,15 @@ static const R_CallMethodDef CallEntries[] = {
   {"Rfast_col_cum_prods", (DL_FUNC) &Rfast_col_cum_prods, 1},
   {"Rfast_col_meds", (DL_FUNC) &Rfast_col_meds, 3},
   {"Rfast_col_min_indices", (DL_FUNC) &Rfast_col_min_indices, 1},
-  {"Rfast_col_min", (DL_FUNC) &Rfast_col_min, 1},
+  {"Rfast_col_min", (DL_FUNC) &Rfast_col_min, 2},
   {"Rfast_col_sums", (DL_FUNC) &Rfast_col_sums, 3},
-  {"Rfast_col_min_max", (DL_FUNC) &Rfast_col_min_max, 1},
+  {"Rfast_col_min_max", (DL_FUNC) &Rfast_col_min_max, 2},
   {"Rfast_col_max_indices", (DL_FUNC) &Rfast_col_max_indices, 1},
-  {"Rfast_col_max", (DL_FUNC) &Rfast_col_max, 1},
+  {"Rfast_col_max", (DL_FUNC) &Rfast_col_max, 2},
   {"Rfast_col_means", (DL_FUNC) &Rfast_col_means, 2},
   {"Rfast_col_nth", (DL_FUNC) &Rfast_col_nth, 6},
   {"Rfast_col_len_sort_un_int", (DL_FUNC) &Rfast_col_len_sort_un_int, 1},
-  {"Rfast_col_ranks", (DL_FUNC) &Rfast_col_ranks, 4},
+  {"Rfast_col_ranks", (DL_FUNC) &Rfast_col_ranks, 5},
   {"Rfast_col_tabulate", (DL_FUNC) &Rfast_col_tabulate, 2},
   {"Rfast_col_shuffle", (DL_FUNC) &Rfast_col_shuffle, 1},
   {"Rfast_col_true", (DL_FUNC) &Rfast_col_true, 1},
@@ -479,10 +476,7 @@ static const R_CallMethodDef CallEntries[] = {
 
   {"Rfast_col_all_p", (DL_FUNC) &Rfast_col_all_p, 1},
   {"Rfast_col_count_values_p", (DL_FUNC) &Rfast_col_count_values_p, 2},
-  {"Rfast_col_max_p", (DL_FUNC) &Rfast_col_max_p, 1},
-  {"Rfast_col_min_p", (DL_FUNC) &Rfast_col_min_p, 1},
   {"Rfast_col_nth_p", (DL_FUNC) &Rfast_col_nth_p, 5},
-  {"Rfast_col_ranks_p", (DL_FUNC) &Rfast_col_ranks_p, 4},
   {"Rfast_col_sums_p", (DL_FUNC) &Rfast_col_sums_p, 1},
   {"Rfast_col_order_p", (DL_FUNC) &Rfast_col_order_p, 3},
   {"Rfast_mat_mult_p", (DL_FUNC) &Rfast_mat_mult_p, 4},
